==> aws-java-sdk-opsworks-1.10.50-sources.jar: com/amazonaws/services/opsworks/model/transform/DescribeStackProvisioningParametersResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.opsworks.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.opsworks.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * DescribeStackProvisioningParametersResult JSON Unmarshaller
 */
public class DescribeStackProvisioningParametersResultJsonUnmarshaller
        implements
        Unmarshaller<DescribeStackProvisioningParametersResult, JsonUnmarshallerContext> {

    public DescribeStackProvisioningParametersResult unmarshall(
            JsonUnmarshallerContext context) throws Exception {
        DescribeStackProvisioningParametersResult describeStackProvisioningParametersResult = new DescribeStackProvisioningParametersResult();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("AgentInstallerUrl", targetDepth)) {
                    context.nextToken();
                    describeStackProvisioningParametersResult
                            .setAgentInstallerUrl(StringJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
                if (context.testExpression("Parameters", targetDepth)) {
                    context.nextToken();
                    describeStackProvisioningParametersResult
                            .setParameters(new MapUnmarshaller<String, String>(
                                    StringJsonUnmarshaller.getInstance(),
                                    StringJsonUnmarshaller.getInstance())
                                    .unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return describeStackProvisioningParametersResult;
    }

    private static DescribeStackProvisioningParametersResultJsonUnmarshaller instance;

    public static DescribeStackProvisioningParametersResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeStackProvisioningParametersResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-opsworks-1.11.23-sources.jar: com/amazonaws/services/opsworks/model/transform/DescribeStackProvisioningParametersResultJsonUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.opsworks.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.opsworks.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * DescribeStackProvisioningParametersResult JSON Unmarshaller
 */
public class DescribeStackProvisioningParametersResultJsonUnmarshaller
        implements
        Unmarshaller<DescribeStackProvisioningParametersResult, JsonUnmarshallerContext> {

    public DescribeStackProvisioningParametersResult unmarshall(
            JsonUnmarshallerContext context) throws Exception {
        DescribeStackProvisioningParametersResult describeStackProvisioningParametersResult = new DescribeStackProvisioningParametersResult();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("AgentInstallerUrl", targetDepth)) {
                    context.nextToken();
                    describeStackProvisioningParametersResult
                            .setAgentInstallerUrl(context.getUnmarshaller(
                                    String.class).unmarshall(context));
                }
                if (context.testExpression("Parameters", targetDepth)) {
                    context.nextToken();
                    describeStackProvisioningParametersResult
                            .setParameters(new MapUnmarshaller<String, String>(
                                    context.getUnmarshaller(String.class),
                                    context.getUnmarshaller(String.class))
                                    .unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return describeStackProvisioningParametersResult;
    }

    private static DescribeStackProvisioningParametersResultJsonUnmarshaller instance;

    public static DescribeStackProvisioningParametersResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeStackProvisioningParametersResultJsonUnmarshaller();
        return instance;
    }
}
